@@ -5,6 +5,7 @@ srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
 PKG_NAME="libgnomecups"
+REQUIRED_AUTOMAKE_VERSION=1.7
 
 (test -f $srcdir/configure.in \
   && test -f $srcdir/AUTHORS \
@@ -18,4 +19,4 @@ which gnome-autogen.sh || {
     echo "You need to install gnome-common from the GNOME CVS"
     exit 1
 }
-USE_GNOME2_MACROS=1 . gnome-autogen.sh
+. gnome-autogen.sh
